****************************
Stepwise — Molecular Biology
****************************

.. image:: https://img.shields.io/pypi/v/stepwise_mol_bio.svg
   :target: https://pypi.python.org/pypi/stepwise_mol_bio

.. image:: https://img.shields.io/pypi/pyversions/stepwise_mol_bio.svg
   :target: https://pypi.python.org/pypi/stepwise_mol_bio

.. image:: https://img.shields.io/readthedocs/stepwise_mol_bio.svg
   :target: https://stepwise_mol_bio.readthedocs.io/en/latest/?badge=latest

.. image:: https://img.shields.io/github/workflow/status/kalekundert/stepwise_mol_bio/Test%20and%20release/master
   :target: https://github.com/kalekundert/stepwise_mol_bio/actions

.. image:: https://img.shields.io/coveralls/kalekundert/stepwise_mol_bio.svg
   :target: https://coveralls.io/github/kalekundert/stepwise_mol_bio?branch=master

Installation
============
Install ``stepwise_mol_bio`` using ``pip``::

    $ pip install stepwise_mol_bio

Usage
=====
Coming soon...
